// ignore_for_file: curly_braces_in_flow_control_structures, prefer_is_empty

import 'dart:async';
import 'dart:developer';

import 'package:hub/backend/api_requests/api_calls.dart';
import 'package:hub/shared/components/molecules/modules/index.dart';
import 'package:hub/shared/helpers/database/database_helper.dart';

import 'package:rxdart/rxdart.dart';
import 'package:sqflite/sqflite.dart';

abstract class LicenseRemoteDataSource {
  Future<bool> fetchLicenses(bool isNewVersion);
  Future<void> cleanLicense();
  Future<void> processLicense();
  Future<void> setupLicense(Database database, bool isNewVersion);
}

class LicenseRemoteDataSourceImpl implements LicenseRemoteDataSource {
  static final LicenseRemoteDataSourceImpl _instance = LicenseRemoteDataSourceImpl._internal();
  factory LicenseRemoteDataSourceImpl() => _instance;
  LicenseRemoteDataSourceImpl._internal();

  final Completer<void> _saveCompleter = Completer<void>();

  @override
  Future<void> processLicense() async {
    // if (body['key'] == Module.pets.value && body['display'] == 'VISIVEL') {
    //   await LicenseHelper().s(Module.petsHistory.value, body);
    // }
    // final bool isAboutProperty = AboutPropertyModules.values.contains(body['key']);
    // final bool isVisible = body['display'] == 'VISIVEL';
    // log('contains () => ${body['key']} - $isAboutProperty');
    // if (isAboutProperty && isVisible) {
    //   await LicenseHelper().s(Module.aboutProperty.value, body);
    // }
  }
  @override
  Future<void> cleanLicense() async {
    LicenseRepositoryImpl.license.add([]);
  }

  @override
  Future<void> setupLicense(Database database, bool isNewVersion) async {
    log('(B) => license');

    final List<String> inactiveModuleKey = InactiveModuleKey.values.map((e) => e.value).toList();
    final List<String> activeModuleKey = ActiveModuleKey.values.map((e) => e.value).toList();
    final List<String> disabledModuleKey = DisabledModuleKey.values.map((e) => e.value).toList();

    await LicenseLocalDataSourceImpl().setByKey(inactiveModuleKey, 'INVISIVEL');
    await LicenseLocalDataSourceImpl().setByKey(activeModuleKey, 'VISIVEL');
    if (isNewVersion == true) {
      await LicenseLocalDataSourceImpl().setByKey(disabledModuleKey, 'VISIVEL');
      await LicenseLocalDataSourceImpl().setByKey([Modules.aboutProperty.value], 'VISIVEL');
    } else {
      await LicenseLocalDataSourceImpl().setByKey(disabledModuleKey, 'DESABILITADO');
    }

    LicenseRepositoryImpl.license.add([...activeModuleKey]);
    _saveCompleter.complete();
  }

  @override
  Future<bool> fetchLicenses(bool isNewVersion) async {
    log('(A) => license');
    try {
      log('Obtendo licenças...');
      final response = await PhpGroup.getLicense();
      final dynamic responseBody = response.jsonBody;
      log('Licenças obtidas: $responseBody');

      if (response.jsonBody is! List<dynamic>) {
        late final String error;
        if (response.jsonBody is Map<String, dynamic>)
          error = response.jsonBody['error_msg'];
        else
          error = 'Erro desconhecido';

        throw Exception('Erro ao consultar licenças: $error');
      }

      if (responseBody == []) {
        await setupLicense(DatabaseStorage.database, isNewVersion);
        LicenseRepositoryImpl.license.add([]);
        return false;
      }

      List<Future<void>> saveOperations = [];
      for (var element in responseBody) {
        if (licenseContainsKey(element['key'])) {
          saveOperations.add(_saveModule(element));
        }
      }
      await Future.wait(saveOperations);

      log('() => License stream add');
      LicenseRepositoryImpl.license.add(responseBody);
      _saveCompleter.complete();
      return true;
    } catch (e) {
      log('Erro ao obter licenças: $e');
      await setupLicense(DatabaseStorage.database, isNewVersion);
      return false;
    }
  }

  Future<void> waitForSaveCompletion() async {
    await _saveCompleter.future;
  }

  static bool licenseContainsKey(final String key) {
    return Modules.values.map((e) => e.value).toList().contains(key);
  }

  static Future<void> _saveModule(final dynamic body) async {
    if (body is! Map<String, dynamic>) return;
    log('Salvando módulo: ${body.toString()}');
    await LicenseLocalDataSourceImpl().s(body['key'], body);
  }
}
