import 'package:flutter/material.dart';
import 'package:hub/flutter_flow/internationalization.dart';
import 'package:hub/flutter_flow/nav/nav.dart';
import 'package:hub/shared/components/molecules/modules/index.dart';

enum Module implements BaseModule {
  providerSchedule,
  deliverySchedule,
  fastPass,
  completeSchedule,
  orders,
  reservations,
  visitors,
  vehicles,
  residents,
  openedVisits,
  qrCode,
  pets,
  access,
  liberations,
  messages,
  aboutProperty,
  petsHistory,
  peopleOnTheProperty,
  settings,
  logout;

  @override
  String get value {
    switch (this) {
      case Module.messages:
        return 'FRE-HUB-MESSAGES';
      case Module.liberations:
        return 'FRE-HUB-LIBERATIONS';
      case Module.reservations:
        return 'FRE-HUB-RESERVATIONS';
      case Module.access:
        return 'FRE-HUB-ACCESS';
      case Module.openedVisits:
        return 'FRE-HUB-OPENED-VISITS';
      case Module.vehicles:
        return 'FRE-HUB-VEHICLES';
      case Module.residents:
        return 'FRE-HUB-RESIDENTS';
      case Module.pets:
        return 'FRE-HUB-PETS';
      case Module.orders:
        return 'FRE-HUB-ORDERS';
      case Module.completeSchedule:
        return 'FRE-HUB-COMPLETE-SCHEDULE';
      case Module.providerSchedule:
        return 'FRE-HUB-AGE-PROV-PRESTADOR';
      case Module.deliverySchedule:
        return 'FRE-HUB-AGE-PROV-DELIVERY';
      case Module.aboutProperty:
        return 'FRE-HUB-PROPERTY';
      case Module.fastPass:
        return 'FRE-HUB-FASTPASS';
      case Module.visitors:
        return 'FRE-HUB-VISITORS';
      case Module.qrCode:
        return 'FRE-HUB-QRCODE';
      case Module.peopleOnTheProperty:
        return 'FRE-HUB-PEOPLE';
      case Module.petsHistory:
        return 'FRE-HUB-PETS-HISTORY';
      default:
        return '';
    }
  }

  @override
  String get name {
    switch (this) {
      case Module.messages:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Mensagens',
          enText: 'Messages History',
        );
      case Module.liberations:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Liberações',
          enText: 'Liberations History',
        );
      case Module.reservations:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Reservas',
          enText: 'Reservations',
        );
      case Module.access:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Acessos',
          enText: 'Access History',
        );
      case Module.openedVisits:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Visitas em Aberto',
          enText: 'Opened Visits',
        );
      case Module.vehicles:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Veículos',
          enText: 'Vehicles',
        );
      case Module.residents:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Moradores',
          enText: 'Residents',
        );
      case Module.pets:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Pets',
          enText: 'Pets',
        );
      case Module.petsHistory:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Pets',
          enText: 'Pets',
        );
      case Module.peopleOnTheProperty:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Pessoas na Propriedade',
          enText: 'People on the Property',
        );
      case Module.orders:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Minhas Encomendas',
          enText: 'My Orders',
        );
      case Module.completeSchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agenda Completa',
          enText: 'Complete Schedule',
        );
      case Module.providerSchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agendar Prestadores',
          enText: 'Schedule Providers',
        );
      case Module.deliverySchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agendar Delivery',
          enText: 'Schedule Delivery',
        );
      case Module.fastPass:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Fast Pass',
          enText: 'Fast Pass',
        );
      case Module.qrCode:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'QRCode de Acesso',
          enText: 'Access QRCode',
        );
      case Module.visitors:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Cadastrar Visitantes',
          enText: 'Register Visitors',
        );
      case Module.aboutProperty:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Sobre a Propriedade',
          enText: 'About the Property',
        );
      case Module.settings:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Configurações',
          enText: 'Settings',
        );
      case Module.logout:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Sair',
          enText: 'Logout',
        );
    }
  }

  @override
  IconData get icon {
    switch (this) {
      case Module.messages:
        return Icons.chat_outlined;
      case Module.liberations:
        return Icons.how_to_reg_outlined;
      case Module.reservations:
        return Icons.event_available;
      case Module.access:
        return Icons.transfer_within_a_station_outlined;
      case Module.openedVisits:
        return Icons.perm_contact_calendar;
      case Module.vehicles:
        return Icons.directions_car;
      case Module.residents:
        return Icons.groups;
      case Module.pets:
        return Icons.pets;
      case Module.petsHistory:
        return Icons.pets;
      case Module.peopleOnTheProperty:
        return Icons.groups;
      case Module.orders:
        return Icons.inventory_2_outlined;
      case Module.completeSchedule:
        return Icons.event;
      case Module.providerSchedule:
        return Icons.engineering_outlined;
      case Module.deliverySchedule:
        return Icons.sports_motorsports_outlined;
      case Module.fastPass:
        return Icons.attach_email_outlined;
      case Module.qrCode:
        return Icons.qr_code;
      case Module.visitors:
        return Icons.person_add_alt_1_outlined;
      case Module.aboutProperty:
        return Icons.home;
      case Module.settings:
        return Icons.settings;
      case Module.logout:
        return Icons.logout;
    }
  }

  @override
  String get route {
    switch (this) {
      case Module.messages:
        return '/messageHistoryPage';
      case Module.liberations:
        return '/liberationHistory';
      case Module.reservations:
        return '/reservation';
      case Module.access:
        return '/acessHistoryPage';
      case Module.openedVisits:
        return '/visitsOnThePropertyPage';
      case Module.vehicles:
        return '/vehiclesOnThePropertyPage';
      case Module.residents:
        return '/residentsOnThePropertyPage';
      case Module.pets:
        return '/petsPage';
      case Module.petsHistory:
        return '/petsHistoryPage';
      case Module.peopleOnTheProperty:
        return '/peopleOnThePropertyPage';
      case Module.orders:
        return '/packageOrder';
      case Module.completeSchedule:
        return '/scheduleCompleteVisitPage';
      case Module.providerSchedule:
        return '/provisionalSchedule';
      case Module.aboutProperty:
        return '/aboutProperty';
      case Module.deliverySchedule:
        return '/deliverySchedule';
      case Module.fastPass:
        return '/fastPassPage';
      case Module.qrCode:
        return '/qrCodePage';
      case Module.visitors:
        return '/registerVisitorPage';
      case Module.settings:
        return '/preferencesSettings';
      case Module.logout:
        return '/WelcomePage';
      default:
        return '';
    }
  }
}

enum HomeMenuEntries implements BaseModule {
  providerSchedule,
  deliverySchedule,
  fastPass,
  completeSchedule,
  orders,
  reservations,
  visitors,
  qrCode,
  pets,
  access,
  liberations,
  messages,
  aboutProperty,
  peopleOnTheProperty,
  settings;

  @override
  String get value {
    switch (this) {
      case HomeMenuEntries.messages:
        return 'FRE-HUB-MESSAGES';
      case HomeMenuEntries.liberations:
        return 'FRE-HUB-LIBERATIONS';
      case HomeMenuEntries.reservations:
        return 'FRE-HUB-RESERVATIONS';
      case HomeMenuEntries.access:
        return 'FRE-HUB-ACCESS';
      case HomeMenuEntries.pets:
        return 'FRE-HUB-PETS';
      case HomeMenuEntries.orders:
        return 'FRE-HUB-ORDERS';
      case HomeMenuEntries.completeSchedule:
        return 'FRE-HUB-COMPLETE-SCHEDULE';
      case HomeMenuEntries.providerSchedule:
        return 'FRE-HUB-AGE-PROV-PRESTADOR';
      case HomeMenuEntries.deliverySchedule:
        return 'FRE-HUB-AGE-PROV-DELIVERY';
      case HomeMenuEntries.aboutProperty:
        return 'FRE-HUB-PROPERTY';
      case HomeMenuEntries.fastPass:
        return 'FRE-HUB-FASTPASS';
      case HomeMenuEntries.visitors:
        return 'FRE-HUB-VISITORS';
      case HomeMenuEntries.qrCode:
        return 'FRE-HUB-QRCODE';
      case HomeMenuEntries.peopleOnTheProperty:
        return 'FRE-HUB-PEOPLE';
      default:
        return '';
    }
  }

  @override
  String get name {
    switch (this) {
      case HomeMenuEntries.messages:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Mensagens',
          enText: 'Messages History',
        );
      case HomeMenuEntries.liberations:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Liberações',
          enText: 'Liberations History',
        );
      case HomeMenuEntries.reservations:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Reservas',
          enText: 'Reservations',
        );
      case HomeMenuEntries.access:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Acessos',
          enText: 'Access History',
        );
      case HomeMenuEntries.pets:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Pets',
          enText: 'Pets',
        );
      case HomeMenuEntries.peopleOnTheProperty:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Pessoas na Propriedade',
          enText: 'People on the Property',
        );
      case HomeMenuEntries.orders:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Minhas Encomendas',
          enText: 'My Orders',
        );
      case HomeMenuEntries.completeSchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agenda Completa',
          enText: 'Complete Schedule',
        );
      case HomeMenuEntries.providerSchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agendar Prestadores',
          enText: 'Schedule Providers',
        );
      case HomeMenuEntries.deliverySchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agendar Delivery',
          enText: 'Schedule Delivery',
        );
      case HomeMenuEntries.fastPass:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Fast Pass',
          enText: 'Fast Pass',
        );
      case HomeMenuEntries.qrCode:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'QRCode de Acesso',
          enText: 'Access QRCode',
        );
      case HomeMenuEntries.visitors:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Cadastrar Visitantes',
          enText: 'Register Visitors',
        );
      case HomeMenuEntries.aboutProperty:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Sobre a Propriedade',
          enText: 'About the Property',
        );
      case HomeMenuEntries.settings:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Configurações',
          enText: 'Settings',
        );
    }
  }

  @override
  IconData get icon {
    switch (this) {
      case HomeMenuEntries.messages:
        return Icons.chat_outlined;
      case HomeMenuEntries.liberations:
        return Icons.how_to_reg_outlined;
      case HomeMenuEntries.reservations:
        return Icons.event_available;
      case HomeMenuEntries.access:
        return Icons.transfer_within_a_station_outlined;
      case HomeMenuEntries.pets:
        return Icons.pets;
      case HomeMenuEntries.peopleOnTheProperty:
        return Icons.groups;
      case HomeMenuEntries.orders:
        return Icons.inventory_2_outlined;
      case HomeMenuEntries.completeSchedule:
        return Icons.event;
      case HomeMenuEntries.providerSchedule:
        return Icons.engineering_outlined;
      case HomeMenuEntries.deliverySchedule:
        return Icons.sports_motorsports_outlined;
      case HomeMenuEntries.fastPass:
        return Icons.attach_email_outlined;
      case HomeMenuEntries.qrCode:
        return Icons.qr_code;
      case HomeMenuEntries.visitors:
        return Icons.person_add_alt_1_outlined;
      case HomeMenuEntries.aboutProperty:
        return Icons.home;
      case HomeMenuEntries.settings:
        return Icons.settings;
    }
  }

  @override
  String get route {
    switch (this) {
      case HomeMenuEntries.messages:
        return '/messageHistoryPage';
      case HomeMenuEntries.liberations:
        return '/liberationHistory';
      case HomeMenuEntries.reservations:
        return '/reservation';
      case HomeMenuEntries.access:
        return '/acessHistoryPage';
      case HomeMenuEntries.pets:
        return '/petsPage';
      case HomeMenuEntries.peopleOnTheProperty:
        return '/peopleOnThePropertyPage';
      case HomeMenuEntries.orders:
        return '/packageOrder';
      case HomeMenuEntries.completeSchedule:
        return '/scheduleCompleteVisitPage';
      case HomeMenuEntries.providerSchedule:
        return '/provisionalSchedule';
      case HomeMenuEntries.aboutProperty:
        return '/aboutProperty';
      case HomeMenuEntries.deliverySchedule:
        return '/deliverySchedule';
      case HomeMenuEntries.fastPass:
        return '/fastPassPage';
      case HomeMenuEntries.qrCode:
        return '/qrCodePage';
      case HomeMenuEntries.visitors:
        return '/registerVisitorPage';
      case HomeMenuEntries.settings:
        return '/preferencesSettings';
      default:
        return '';
    }
  }
}

enum DrawerMenuEntries implements BaseModule {
  providerSchedule,
  deliverySchedule,
  fastPass,
  completeSchedule,
  orders,
  reservations,
  visitors,
  qrCode,
  pets,
  access,
  liberations,
  messages,
  aboutProperty,
  peopleOnTheProperty,
  settings,
  logout;

  @override
  String get value {
    switch (this) {
      case DrawerMenuEntries.messages:
        return 'FRE-HUB-MESSAGES';
      case DrawerMenuEntries.liberations:
        return 'FRE-HUB-LIBERATIONS';
      case DrawerMenuEntries.reservations:
        return 'FRE-HUB-RESERVATIONS';
      case DrawerMenuEntries.access:
        return 'FRE-HUB-ACCESS';
      case DrawerMenuEntries.pets:
        return 'FRE-HUB-PETS';
      case DrawerMenuEntries.orders:
        return 'FRE-HUB-ORDERS';
      case DrawerMenuEntries.completeSchedule:
        return 'FRE-HUB-COMPLETE-SCHEDULE';
      case DrawerMenuEntries.providerSchedule:
        return 'FRE-HUB-AGE-PROV-PRESTADOR';
      case DrawerMenuEntries.deliverySchedule:
        return 'FRE-HUB-AGE-PROV-DELIVERY';
      case DrawerMenuEntries.aboutProperty:
        return 'FRE-HUB-PROPERTY';
      case DrawerMenuEntries.fastPass:
        return 'FRE-HUB-FASTPASS';
      case DrawerMenuEntries.visitors:
        return 'FRE-HUB-VISITORS';
      case DrawerMenuEntries.qrCode:
        return 'FRE-HUB-QRCODE';
      case DrawerMenuEntries.peopleOnTheProperty:
        return 'FRE-HUB-PEOPLE';
      default:
        return '';
    }
  }

  @override
  String get name {
    switch (this) {
      case DrawerMenuEntries.messages:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Mensagens',
          enText: 'Messages History',
        );
      case DrawerMenuEntries.liberations:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Liberações',
          enText: 'Liberations History',
        );
      case DrawerMenuEntries.reservations:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Reservas',
          enText: 'Reservations',
        );
      case DrawerMenuEntries.access:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Acessos',
          enText: 'Access History',
        );
      case DrawerMenuEntries.pets:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Pets',
          enText: 'Pets',
        );
      case DrawerMenuEntries.peopleOnTheProperty:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Pessoas na Propriedade',
          enText: 'People on the Property',
        );
      case DrawerMenuEntries.orders:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Minhas Encomendas',
          enText: 'My Orders',
        );
      case DrawerMenuEntries.completeSchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agenda Completa',
          enText: 'Complete Schedule',
        );
      case DrawerMenuEntries.providerSchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agendar Prestadores',
          enText: 'Schedule Providers',
        );
      case DrawerMenuEntries.deliverySchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agendar Delivery',
          enText: 'Schedule Delivery',
        );
      case DrawerMenuEntries.fastPass:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Fast Pass',
          enText: 'Fast Pass',
        );
      case DrawerMenuEntries.qrCode:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'QRCode de Acesso',
          enText: 'Access QRCode',
        );
      case DrawerMenuEntries.visitors:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Cadastrar Visitantes',
          enText: 'Register Visitors',
        );
      case DrawerMenuEntries.aboutProperty:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Sobre a Propriedade',
          enText: 'About the Property',
        );
      case DrawerMenuEntries.settings:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Configurações',
          enText: 'Settings',
        );
      case DrawerMenuEntries.logout:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Sair',
          enText: 'Logout',
        );
    }
  }

  @override
  IconData get icon {
    switch (this) {
      case DrawerMenuEntries.messages:
        return Icons.chat_outlined;
      case DrawerMenuEntries.liberations:
        return Icons.how_to_reg_outlined;
      case DrawerMenuEntries.reservations:
        return Icons.event_available;
      case DrawerMenuEntries.access:
        return Icons.transfer_within_a_station_outlined;
      case DrawerMenuEntries.pets:
        return Icons.pets;
      case DrawerMenuEntries.peopleOnTheProperty:
        return Icons.groups;
      case DrawerMenuEntries.orders:
        return Icons.inventory_2_outlined;
      case DrawerMenuEntries.completeSchedule:
        return Icons.event;
      case DrawerMenuEntries.providerSchedule:
        return Icons.engineering_outlined;
      case DrawerMenuEntries.deliverySchedule:
        return Icons.sports_motorsports_outlined;
      case DrawerMenuEntries.fastPass:
        return Icons.attach_email_outlined;
      case DrawerMenuEntries.qrCode:
        return Icons.qr_code;
      case DrawerMenuEntries.visitors:
        return Icons.person_add_alt_1_outlined;
      case DrawerMenuEntries.aboutProperty:
        return Icons.home;
      case DrawerMenuEntries.settings:
        return Icons.settings;
      case DrawerMenuEntries.logout:
        return Icons.exit_to_app;
    }
  }

  @override
  String get route {
    switch (this) {
      case DrawerMenuEntries.messages:
        return '/messageHistoryPage';
      case DrawerMenuEntries.liberations:
        return '/liberationHistory';
      case DrawerMenuEntries.reservations:
        return '/reservation';
      case DrawerMenuEntries.access:
        return '/acessHistoryPage';
      case DrawerMenuEntries.pets:
        return '/petsPage';
      case DrawerMenuEntries.peopleOnTheProperty:
        return '/peopleOnThePropertyPage';
      case DrawerMenuEntries.orders:
        return '/packageOrder';
      case DrawerMenuEntries.completeSchedule:
        return '/scheduleCompleteVisitPage';
      case DrawerMenuEntries.providerSchedule:
        return '/provisionalSchedule';
      case DrawerMenuEntries.aboutProperty:
        return '/aboutProperty';
      case DrawerMenuEntries.deliverySchedule:
        return '/deliverySchedule';
      case DrawerMenuEntries.fastPass:
        return '/fastPassPage';
      case DrawerMenuEntries.qrCode:
        return '/qrCodePage';
      case DrawerMenuEntries.visitors:
        return '/registerVisitorPage';
      case DrawerMenuEntries.settings:
        return '/preferencesSettings';
      case DrawerMenuEntries.logout:
        return '/WelcomePage';
      default:
        return '';
    }
  }
}
